# arpes.plotting.mask\_tool module

**class arpes.plotting.mask\_tool.MaskTool(**kwargs)\*\*

> Bases: `arpes.plotting.interactive_utils.SaveableTool`,
> [arpes.plotting.interactive\_utils.CursorTool](arpes.plotting.interactive_utils#arpes.plotting.interactive_utils.CursorTool)
> 
> Tool to allow masking data by drawing regions.
> 
> `auto_rebin = False`
> 
> `auto_zero_nans = False`
> 
> **deserialize(json\_data)**
> 
> **serialize()**
> 
> **tool\_handler(doc)**

**arpes.plotting.mask\_tool.mask(data:
Union\[xarray.core.dataarray.DataArray,
xarray.core.dataset.Dataset\],**kwargs)\*\*
